==> xlniuxdata-vipgame-1.0.2-20150210.053540-6-sources.jar: com/xunlei/niux/data/vipgame/vo/bonus/BonusProductCharge.java <==
package com.xunlei.niux.data.vipgame.vo.bonus;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="bonusproductcharge",pkFieldAssign=false,pkFieldName="seqId")
public class BonusProductCharge {
	private Long seqId;
	private String productId;
	private Long totalCount;
	private Long usedCount;
	private Long leftCount;
	private Long bonus;
	private Boolean isValid;
	private String inputTime;
	private String inputBy;
	private String picUrl;
	private String smallPicUrl;
	private Long exchangeCount;
	private String content;
	private String valdateTime;
	
	
	public String getSmallPicUrl() {
		return smallPicUrl;
	}
	public void setSmallPicUrl(String smallPicUrl) {
		this.smallPicUrl = smallPicUrl;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUsedCount() {
		return usedCount;
	}
	public void setUsedCount(Long usedCount) {
		this.usedCount = usedCount;
	}
	public String getValdateTime() {
		return valdateTime;
	}
	public void setValdateTime(String valdateTime) {
		this.valdateTime = valdateTime;
	}
	public String getContent() {
		return content;
	}
	public void setContent(String content) {
		this.content = content;
	}
	public Long getExchangeCount() {
		return exchangeCount;
	}
	public void setExchangeCount(Long exchangeCount) {
		this.exchangeCount = exchangeCount;
	}
	public String getPicUrl() {
		return picUrl;
	}
	public void setPicUrl(String picUrl) {
		this.picUrl = picUrl;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public Boolean getIsValid() {
		return isValid;
	}
	public void setIsValid(Boolean isValid) {
		this.isValid = isValid;
	}
	public String getProductId() {
		return productId;
	}
	public void setProductId(String productId) {
		this.productId = productId;
	}
	public Long getTotalCount() {
		return totalCount;
	}
	public void setTotalCount(Long totalCount) {
		this.totalCount = totalCount;
	}
	public Long getLeftCount() {
		return leftCount;
	}
	public void setLeftCount(Long leftCount) {
		this.leftCount = leftCount;
	}
	public Long getBonus() {
		return bonus;
	}
	public void setBonus(Long bonus) {
		this.bonus = bonus;
	}

	
	
}

==> xlniuxdata-vipgame-1.0.25-20150908.083901-3-sources.jar: com/xunlei/niux/data/vipgame/vo/bonus/BonusProductCharge.java <==
package com.xunlei.niux.data.vipgame.vo.bonus;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="bonusproductcharge",pkFieldAssign=false,pkFieldName="seqId")
public class BonusProductCharge {
	private Long seqId;
	private String productId;
	private Long totalCount;
	private Long usedCount;
	private Long leftCount;
	private Long bonus;
	private Boolean isValid;
	private String inputTime;
	private String inputBy;
	private String picUrl;
	private String smallPicUrl;
	private Long exchangeCount;
	private String content;
	private String valdateTime;
	private Integer orderNum;
	private String firstLetter;
	
	
	public String getSmallPicUrl() {
		return smallPicUrl;
	}
	public void setSmallPicUrl(String smallPicUrl) {
		this.smallPicUrl = smallPicUrl;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUsedCount() {
		return usedCount;
	}
	public void setUsedCount(Long usedCount) {
		this.usedCount = usedCount;
	}
	public String getValdateTime() {
		return valdateTime;
	}
	public void setValdateTime(String valdateTime) {
		this.valdateTime = valdateTime;
	}
	public String getContent() {
		return content;
	}
	public void setContent(String content) {
		this.content = content;
	}
	public Long getExchangeCount() {
		return exchangeCount;
	}
	public void setExchangeCount(Long exchangeCount) {
		this.exchangeCount = exchangeCount;
	}
	public String getPicUrl() {
		return picUrl;
	}
	public void setPicUrl(String picUrl) {
		this.picUrl = picUrl;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public Boolean getIsValid() {
		return isValid;
	}
	public void setIsValid(Boolean isValid) {
		this.isValid = isValid;
	}
	public String getProductId() {
		return productId;
	}
	public void setProductId(String productId) {
		this.productId = productId;
	}
	public Long getTotalCount() {
		return totalCount;
	}
	public void setTotalCount(Long totalCount) {
		this.totalCount = totalCount;
	}
	public Long getLeftCount() {
		return leftCount;
	}
	public void setLeftCount(Long leftCount) {
		this.leftCount = leftCount;
	}
	public Long getBonus() {
		return bonus;
	}
	public void setBonus(Long bonus) {
		this.bonus = bonus;
	}
	public Integer getOrderNum() {
		return orderNum;
	}
	public void setOrderNum(Integer orderNum) {
		this.orderNum = orderNum;
	}
	public String getFirstLetter() {
		return firstLetter;
	}
	public void setFirstLetter(String firstLetter) {
		this.firstLetter = firstLetter;
	}
	
	
	
}
